درجه بندی عملکرد صندوق‌ها

##### شرکت مدیریت فناوری بورس تهران

###### مرکز پردازش اطلاعات مالی ایران

## درجه بندی عملکرد صندوق‌ها

#### در این بخش درجه بندی عملکرد صندوق‌های سرمایه‌گذاری قابل مشاهده می‌باشد.

توجه داشته باشید :
* درجه بندی عملکرد صندوق‌ها در سه بازه زمانی 1 ساله، 3 ساله و 5 ساله مورد بررسی و محاسبه قرار گرفته است.
* صندوق‌هایی که درجه‌بندی عملکرد آنها تعیین نشده است با مقدار "محاسبه نشده" مشخص شده اند.
* برای کسب اطلاعات بیشتر می‌توانید به «شیوه نامه درجه بندی عملکرد صندوق‌های سرمایه‌گذاری» در سایت موسسه رتبه‌بندی اعتباری برهان مراجعه نمایید.

نام صندوق | عملکرد 1 ساله | عملکرد 3 ساله | عملکرد 5 ساله | تاریخ بروزرسانی
--- | --- | --- | --- | ---
قابل معامله ثروت داريوش | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
مشترك آتيه نوين | 4 | 4 | 4 | 1400/03/29
آرمان كارآفرين | 4 | 4 | 4 | 1400/03/29
آواي سهام كيان | 3 | 3 | 4 | 1400/03/29
اتحاد آرمان اقتصاد | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
اختصاصي بازارگردان تجارت ايرانيان اعتماد | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
اختصاصي بازارگرداني انديشه زرين پاسارگاد | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
اختصاصي بازارگرداني بانك سينا | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
اختصاصي بازارگرداني پست بانك ايران | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
اختصاصي بازارگرداني تاك دانا | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
اختصاصي بازارگرداني حامي اول | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
اختصاصي بازارگرداني دارا داريوش | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
اختصاصي بازارگرداني گروه گردشگري ايرانيان | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
ارزش آفرين گلرنگ | 2 | 3 | 3 | 1400/03/29
ارزش آفرينان دي | 4 | 4 | 4 | 1400/03/29
ارزش كاوان آينده | 3 | 2 | 2 | 1400/03/29
ارمغان يكم ملل | 4 | 4 | 0 محاسبه نشده | 1400/03/29
اعتبار آفرين ايرانيان | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
اعتبار سهام ايرانيان | 1 | 1 | 1 | 1400/03/29
اعتماد كارگزاري بانك ملي ايران | 4 | 5 | 3 | 1400/03/29
اعتماد ملل | 2 | 3 | 3 | 1400/03/29
افرا نماد پايدار | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
افق روشن بانك خاورميانه | 2 | 3 | 3 | 1400/03/29
الماس كوروش | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
امين آشنا ايرانيان | 4 | 4 | 5 | 1400/03/29
امين سامان | 2 | 3 | 3 | 1400/03/29
اندوخته آميتيس | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
اندوخته پايدار سپهر | 2 | 2 | 3 | 1400/03/29
انديشه خبرگان سهام | 3 | 3 | 3 | 1400/03/29
با درآمد ثابت فيروزه آسيا | 2 | 2 | 2 | 1400/03/29
با درآمد ثابت كاريزما | 4 | 4 | 4 | 1400/03/29
با درآمد ثابت كمند | 2 | 3 | 2 | 1400/03/29
باران كارگزاري بانك كشاورزي | 4 | 4 | 4 | 1400/03/29
بازارگرداني آواي زاگرس | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
بازارگرداني چند سهمي سپهر بازار سرمايه | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
بازارگرداني صنعت مس | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
بازارگرداني گسترش صنعت دارو | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
بانك ايران زمين | 2 | 3 | 4 | 1400/03/29
بانك دي | 1 | 1 | 1 | 1400/03/29
بانك گردشگري | 2 | 3 | 4 | 1400/03/29
پاداش سرمايه بهگزين | 5 | 5 | 5 | 1400/03/29
پارند پايدار سپهر | 3 | 3 | 3 | 1400/03/29
پشتوانه سكه طلاي زرافشان اميد ايرانيان | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
پشتوانه طلاي لوتوس | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
پيروزان | 3 | 3 | 4 | 1400/03/29
پيشگامان سرمايه نوآفرين | 1 | 0 محاسبه نشده | 0 محاسبه نشده | 1400/03/29
تجربه ايرانيان | 3 | 3 | 4 | 1400/03/29
توسعه پست بانك | 4 | 4 | 3 | 1400/03/29
توسعه تعاون صبا | 4 | 4 | 4 | 1400/03/29
توسعه سرمايه نيكي | 1 | 1 | 2 | 1400/03/29
توسعه صادرات | 4 | 3 | 2 | 1400/03/29
توسعه فراز اعتماد | 4 | 4 | 3 | 1400/03/29
ثروت آفرين پارسيان | 1 | 1 | 2 | 1400/03/29
ثروت ستارگان | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
جسورانه پارتيان | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
جسورانه رويش لوتوس | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
حكمت آشنا ايرانيان | 5 | 5 | 3 | 1400/03/29
خاتم ايساتيس پويا | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
در اوراق بهادار مبتني بر سكه طلاي كيان | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
دوم اكسير فارابي | 4 | 4 | 2 | 1400/03/29
ذوب آهن نوويرا | 2 | 3 | 4 | 1400/03/29
ره آورد آباد مسكن | 3 | 3 | 3 | 1400/03/29
زرين پارسيان | 2 | 2 | 3 | 1400/03/29
زمرد آگاه | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
زمرد نو ويرا ذوب آهن | 2 | 1 | 1 | 1400/03/29
سپهر اول | 2 | 2 | 2 | 1400/03/29
سپيد دماوند | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
سكه طلا كهربا | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
سهم آشنا | 4 | 5 | 5 | 1400/03/29
سينا | 5 | 4 | 3 | 1400/03/29
شاخصي بازار آشنا | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
شاخصي كارآفرين | 2 | 1 | 1 | 1400/03/29
صندوق اختصاصي بازارگرداني الگوريتمي اميد فارابي | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
صندوق بازارگرداني اختصاصي تصميم ساز | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
صندوق بازارگرداني اختصاصي نوين پيشرو | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
صندوق بازارگرداني حكمت ايرانيان يكم | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
صندوق سرمايه گذاري آواي فرداي زاگرس | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
صندوق سرمايه گذاري اختصاصي بازارگرداني نهايت انديش اقتصاد بيدار | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
صندوق سرمايه گذاري اختصاصي بازارگرداني آسمان زاگرس | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
صندوق سرمايه گذاري اختصاصي بازارگرداني اتحاد بازار سرمايه | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
صندوق سرمايه گذاري اختصاصي بازارگرداني اميد لوتوس پارسيان | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
صندوق سرمايه گذاري اختصاصي بازارگرداني امين | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
صندوق سرمايه گذاري اختصاصي بازارگرداني ايساتيس پويا | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
صندوق سرمايه گذاري اختصاصي بازارگرداني توسعه فولاد مباركه | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
صندوق سرمايه گذاري اختصاصي بازارگرداني مهرگان | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
صندوق سرمايه گذاري اختصاصي بازارگرداني نماد صنعت و معدن | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
صندوق سرمايه گذاري اندوخته توسعه صادرات آرماني | 1 | 2 | 3 | 1400/03/29
صندوق سرمايه گذاري بازارگرداني مپنا ايرانيان | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
صندوق سرمايه گذاري ثروت آفرين تمدن | 2 | 3 | 2 | 1400/03/29
صندوق سرمايه گذاري خصوصي ثروت آفرين فيروزه | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
صندوق سرمايه گذاري درآمد ثابت سرآمد | 1 | 1 | 2 | 1400/03/29
صندوق سرمايه گذاري گنجينه زرين شهر | 1 | 1 | 2 | 1400/03/29
صندوق سرمايه گذاري گوهر نفيس تمدن | 1 | 2 | 3 | 1400/03/29
صندوق سرمايه گذاري مشترك كارگزاري حافظ | 4 | 4 | 3 | 1400/03/29
صندوق سرمايه‌گذاري آتيه ملت | 3 | 3 | 2 | 1400/03/29
صندوق سرمايه‌گذاري آرمان سپهر آشنا | 3 | 3 | 4 | 1400/03/29
صندوق سرمايه‌گذاري آسمان آرماني سهام | 5 | 5 | 5 | 1400/03/29
صندوق سرمايه‌گذاري آهنگ سهام كيان | 3 | 3 | 3 | 1400/03/29
صندوق سرمايه‌گذاري اختصاصي بازارگرداني آرمان انديش | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
صندوق سرمايه‌گذاري اختصاصي بازارگرداني آرمان انصار | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
صندوق سرمايه‌گذاري اختصاصي بازارگرداني آرمان تدبير نقش جهان | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
صندوق سرمايه‌گذاري اختصاصي بازارگرداني ارزش آفرين صندوق بازنشستگي كشوري | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
صندوق سرمايه‌گذاري اختصاصي بازارگرداني افتخار حافظ | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
صندوق سرمايه‌گذاري اختصاصي بازارگرداني اميد ايرانيان | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
صندوق سرمايه‌گذاري اختصاصي بازارگرداني بهمن گستر | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
صندوق سرمايه‌گذاري اختصاصي بازارگرداني توسعه سهام نيكي | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
صندوق سرمايه‌گذاري اختصاصي بازارگرداني توسعه ملي | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
صندوق سرمايه‌گذاري اختصاصي بازارگرداني خبرگان اهداف | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
صندوق سرمايه‌گذاري اختصاصي بازارگرداني خليج فارس | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
صندوق سرمايه‌گذاري اختصاصي بازارگرداني كوشا الگوريتم | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
صندوق سرمايه‌گذاري اختصاصي بازارگرداني گروه دي | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
صندوق سرمايه‌گذاري اختصاصي بازارگرداني گنجينه سپهر صادرات | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
صندوق سرمايه‌گذاري اختصاصي بازارگرداني گوهرفام اميد | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
صندوق سرمايه‌گذاري اختصاصي بازارگرداني لاجورد دماوند | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
صندوق سرمايه‌گذاري اختصاصي بازارگرداني مفيد | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
صندوق سرمايه‌گذاري اختصاصي بازارگرداني ميزان داريك | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
صندوق سرمايه‌گذاري اختصاصي بازارگرداني هوشمند آبان | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
صندوق سرمايه‌گذاري اختصاصي بازارگرداني يكم هامرز | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
صندوق سرمايه‌گذاري اعتبار سرمايه نو آفرين | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
صندوق سرمايه‌گذاري افق ملت | 4 | 3 | 3 | 1400/03/29
صندوق سرمايه‌گذاري امين انصار | 2 | 3 | 3 | 1400/03/29
صندوق سرمايه‌گذاري امين ملت | 2 | 3 | 3 | 1400/03/29
صندوق سرمايه‌گذاري امين يكم فردا | 3 | 3 | 3 | 1400/03/29
صندوق سرمايه‌گذاري اندوخته ملت | 3 | 2 | 3 | 1400/03/29
صندوق سرمايه‌گذاري اوج ملت | 4 | 3 | 4 | 1400/03/29
صندوق سرمايه‌گذاري با درآمد ثابت اميد انصار | 3 | 2 | 3 | 1400/03/29
صندوق سرمايه‌گذاري با درآمد ثابت كاردان | 2 | 2 | 3 | 1400/03/29
صندوق سرمايه‌گذاري با درآمد ثابت كوثر يكم | 3 | 2 | 3 | 1400/03/29
صندوق سرمايه‌گذاري با درآمد ثابت گنجينه اميد ايرانيان | 3 | 2 | 3 | 1400/03/29
صندوق سرمايه‌گذاري با درآمد ثابت مشترك نوين نگر آسيا | 3 | 3 | 2 | 1400/03/29
صندوق سرمايه‌گذاري با درآمد ثابت نگين سامان | 3 | 2 | 2 | 1400/03/29
صندوق سرمايه‌گذاري بازارگرداني اختصاصي پرگار | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
صندوق سرمايه‌گذاري بازارگرداني اكسير سودا | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
صندوق سرمايه‌گذاري بانك توسعه تعاون | 2 | 2 | 3 | 1400/03/29
صندوق سرمايه‌گذاري پاداش سهامداري توسعه يكم | 4 | 2 | 2 | 1400/03/29
صندوق سرمايه‌گذاري پروژه آرمان پرند مپنا | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
صندوق سرمايه‌گذاري تجارت شاخصي كاردان | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
صندوق سرمايه‌گذاري توسعه اندوخته آينده | 5 | 5 | 5 | 1400/03/29
صندوق سرمايه‌گذاري توسعه ممتاز | 5 | 0 محاسبه نشده | 0 محاسبه نشده | 1400/03/29
صندوق سرمايه‌گذاري ثابت حامي | 2 | 2 | 3 | 1400/03/29
صندوق سرمايه‌گذاري ثابت نامي مفيد | 3 | 0 محاسبه نشده | 2 | 1400/03/29
صندوق سرمايه‌گذاري ثروت هامرز | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
صندوق سرمايه‌گذاري جسورانه ستاره برتر | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
صندوق سرمايه‌گذاري جسورانه فناوري بازنشستگي | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
صندوق سرمايه‌گذاري جسورانه فيروزه | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
صندوق سرمايه‌گذاري جسورانه يكم آرمان آتي | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
صندوق سرمايه‌گذاري در اوراق بهادار مبتني بر سكه طلاي مفيد | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
صندوق سرمايه‌گذاري سهام بزرگ كاردان | 3 | 3 | 3 | 1400/03/29
صندوق سرمايه‌گذاري شاخص سي شركت بزرگ فيروزه | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
صندوق سرمايه‌گذاري فيروزه موفقيت | 4 | 5 | 5 | 1400/03/29
صندوق سرمايه‌گذاري قابل معامله سپهر سودمند سينا | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
صندوق سرمايه‌گذاري گنجينه الماس بيمه دي | 3 | 2 | 1 | 1400/03/29
صندوق سرمايه‌گذاري گنجينه رفاه | 2 | 3 | 4 | 1400/03/29
صندوق سرمايه‌گذاري گنجينه يكم آويد | 4 | 3 | 3 | 1400/03/29
صندوق سرمايه‌گذاري مديريت ثروت صندوق بازنشستگي كشوري | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
صندوق سرمايه‌گذاري مشترك آسمان اميد | 3 | 2 | 1 | 1400/03/29
صندوق سرمايه‌گذاري مشترك آسمان خاورميانه | 4 | 5 | 5 | 1400/03/29
صندوق سرمايه‌گذاري مشترك آسمان يكم | 5 | 5 | 5 | 1400/03/29
صندوق سرمايه‌گذاري مشترك اميد توسعه | 3 | 3 | 4 | 1400/03/29
صندوق سرمايه‌گذاري مشترك امين آويد | 2 | 1 | 1 | 1400/03/29
صندوق سرمايه‌گذاري مشترك ايساتيس پوياي يزد | 1 | 2 | 2 | 1400/03/29
صندوق سرمايه‌گذاري مشترك بانك اقتصاد نوين | 3 | 2 | 1 | 1400/03/29
صندوق سرمايه‌گذاري مشترك پارس | 2 | 2 | 2 | 1400/03/29
صندوق سرمايه‌گذاري مشترك پيشتاز | 4 | 4 | 5 | 1400/03/29
صندوق سرمايه‌گذاري مشترك پيشرو | 4 | 4 | 4 | 1400/03/29
صندوق سرمايه‌گذاري مشترك سبحان | 1 | 1 | 2 | 1400/03/29
صندوق سرمايه‌گذاري مشترك صبا | 2 | 3 | 3 | 1400/03/29
صندوق سرمايه‌گذاري مشترك صنعت و معدن | 5 | 4 | 2 | 1400/03/29
صندوق سرمايه‌گذاري مشترك كوثر | 3 | 4 | 3 | 1400/03/29
صندوق سرمايه‌گذاري مشترك گنجينه ارمغان الماس | 2 | 1 | 2 | 1400/03/29
صندوق سرمايه‌گذاري مشترك گنجينه الماس پايدار | 4 | 4 | 4 | 1400/03/29
صندوق سرمايه‌گذاري مشترك گنجينه مهر | 3 | 3 | 0 محاسبه نشده | 1400/03/29
صندوق سرمايه‌گذاري مشترك مبين سرمايه | 2 | 2 | 2 | 1400/03/29
صندوق سرمايه‌گذاري مشترك مدرسه كسب و كار صوفي رازي | 3 | 2 | 2 | 1400/03/29
صندوق سرمايه‌گذاري مشترك نويد انصار | 4 | 5 | 4 | 1400/03/29
صندوق سرمايه‌گذاري مشترك نيكوكاري نداي اميد | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
صندوق سرمايه‌گذاري مشترك يكم آبان | 3 | 2 | 1 | 1400/03/29
صندوق سرمايه‌گذاري نگين رفاه | 3 | 3 | 4 | 1400/03/29
صندوق قابل معامله ماني | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
طلاي سرخ نو ويرا | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
قابل معامله آتيه درخشان مس | 4 | 4 | 4 | 1400/03/29
قابل معامله آرمان آتي كوثر | 3 | 3 | 3 | 1400/03/29
قابل معامله آواي معيار | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
قابل معامله ارزش آفرين بيدار | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
قابل معامله ارمغان ايرانيان | 5 | 4 | 5 | 1400/03/29
قابل معامله اعتماد آفرين پارسيان | 3 | 3 | 3 | 1400/03/29
قابل معامله اعتماد داريك | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
قابل معامله امين تدبيرگران فردا | 4 | 3 | 3 | 1400/03/29
قابل معامله انديشه ورزان صبا تأمين | 3 | 2 | 2 | 1400/03/29
قابل معامله با درآمد ثابت تصميم | 3 | 3 | 2 | 1400/03/29
قابل معامله با درآمد ثابت كيان | 4 | 3 | 3 | 1400/03/29
قابل معامله بذر اميد آفرين | 3 | 3 | 3 | 1400/03/29
قابل معامله پاداش سرمايه پارس | 3 | 2 | 3 | 1400/03/29
قابل معامله پالايشي يكم | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
قابل معامله توازن معيار | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
قابل معامله ثبات ويستا | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
قابل معامله دارا الگوريتم | 2 | 1 | 1 | 1400/03/29
قابل معامله زرين كوروش | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
قابل معامله سپر سرمايه بيدار | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
قابل معامله سپهر انديشه نوين | 5 | 5 | 3 | 1400/03/29
قابل معامله سپهر خبرگان نفت | 3 | 3 | 2 | 1400/03/29
قابل معامله سپهر كاريزما | 4 | 4 | 4 | 1400/03/29
قابل معامله سرو سودمند مدبران | 5 | 0 محاسبه نشده | 0 محاسبه نشده | 1400/03/29
قابل معامله فراز داريك | 5 | 4 | 3 | 1400/03/29
قابل معامله كامياب آشنا | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
قابل معامله گنجينه آينده روشن | 5 | 4 | 4 | 1400/03/29
قابل معامله هستي بخش آگاه | 5 | 5 | 5 | 1400/03/29
قابل معامله هماي آگاه | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
قابل معامله واسطه گري مالي يكم | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
قابل معامله ياقوت آگاه | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
كارگزاري پارسيان | 3 | 4 | 4 | 1400/03/29
گروه زعفران سحرخيز | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
گسترش فرداي ايرانيان | 5 | 5 | 5 | 1400/03/29
لوتوس پارسيان | 2 | 3 | 3 | 1400/03/29
مختلط كاريزما | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
مشترك آگاه | 3 | 3 | 3 | 1400/03/29
مشترك افق | 4 | 4 | 3 | 1400/03/29
مشترك افق كارگزاري بانك خاورميانه | 3 | 4 | 4 | 1400/03/29
مشترك البرز | 1 | 1 | 1 | 1400/03/29
مشترك انديشه فردا | 3 | 5 | 5 | 1400/03/29
مشترك بانك خاورميانه | 2 | 3 | 4 | 1400/03/29
مشترك بانك مسكن | 3 | 1 | 1 | 1400/03/29
مشترك بورسيران | 3 | 4 | 4 | 1400/03/29
مشترك پويا | 2 | 2 | 2 | 1400/03/29
مشترك تدبيرگران فردا | 3 | 3 | 3 | 1400/03/29
مشترك توسعه ملي | 3 | 4 | 4 | 1400/03/29
مشترك دماسنج | 1 | 3 | 2 | 1400/03/29
مشترك رشد سامان | 1 | 2 | 3 | 1400/03/29
مشترك سپهر آتي | 3 | 3 | 0 محاسبه نشده | 1400/03/29
مشترك سپهر تدبيرگران | 5 | 5 | 5 | 1400/03/29
مشترك صباي هدف | 1 | 2 | 1 | 1400/03/29
مشترك عقيق | 4 | 3 | 3 | 1400/03/29
مشترك فراز انديش نوين | 3 | 4 | 4 | 1400/03/29
مشترك كارگزاري بانك ملي ايران | 3 | 3 | 3 | 1400/03/29
مشترك كارگزاري كارآفرين | 5 | 5 | 5 | 1400/03/29
مشترك كاريزما | 4 | 4 | 3 | 1400/03/29
مشترك كيمياي كاردان | 3 | 2 | 0 محاسبه نشده | 1400/03/29
مشترك مانا الگوريتم | 3 | 3 | 3 | 1400/03/29
مشترك نقش جهان | 3 | 4 | 4 | 1400/03/29
مشترك نوانديشان | 2 | 0 محاسبه نشده | 0 محاسبه نشده | 1400/03/29
مشترك نوين پايدار | 2 | 2 | 2 | 1400/03/29
مشترك يكم ايرانيان | 3 | 4 | 4 | 1400/03/29
مشترك يكم سامان | 1 | 1 | 1 | 1400/03/29
ميعاد ايرانيان | 3 | 2 | 2 | 1400/03/29
نهال سرمايه ايرانيان | 4 | 4 | 4 | 1400/03/29
نيكوكاري ايتام بركت | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
نيكوكاري جايزه علمي فناوري پيامبر اعظم(ص) | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
نيكوكاري دانشگاه الزهرا | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
نيكوكاري دانشگاه تهران | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
نيكوكاري كشتي ورزش ملي ايران | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
نيكوكاري لوتوس رويان | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
نيكوكاري ميراث ماندگار پاسارگاد | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
نيكوكاري ورزشي پرسپوليس | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----
نيكي گستران | 2 | 1 | 1 | 1400/03/29
هميان سپهر | 3 | 3 | 3 | 1400/03/29
يكم اكسير فارابي | 3 | 3 | 2 | 1400/03/29
يكم كارگزاري بانك كشاورزي | 2 | 2 | 2 | 1400/03/29
يكم نيكوكاري آگاه | 0 محاسبه نشده | 0 محاسبه نشده | 0 محاسبه نشده | -----